/*
 * This file is part of  osso-dsp-headers-rx-44
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Markku Vorne <markku.vorne@nokia.com>
 */

#ifndef __AUDIO_DSPTASK_H__
#define __AUDIO_DSPTASK_H__

#include "dsp_arm_types.h"

#define CHANNELS_1            0x01 // One channel.
#define CHANNELS_2            0x02 // Two channels.
#define DSP_AFMT_U8	      	  0x01 // PCM unsigned 8 bits/sample.
#define DSP_AFMT_S16_LE	      0x02 // PCM signed 16 bits/sample little endian.
#define DSP_AFMT_S16_BE	      0x03 // PCM signed 16 bits/sample big endian.
#define DSP_AFMT_S8	          0x04 // PCM signed 8 bits/sample.
#define DSP_AFMT_U16_LE	      0x05 // PCM unsigned 16 bits/sample little endian.
#define DSP_AFMT_U16_BE	      0x06 // PCM unsigned 16 bits/sample big endian.
#define DSP_AFMT_ALAW         0x07 // PCM A-law companded.
#define DSP_AFMT_ULAW         0x08 // PCM u-law companded.
#define DSP_AFMT_MP3          0x09 // MP3 stream.
#define DSP_AFMT_AAC          0x0A // AAC stream.
#define DSP_AFMT_AMR          0x0B // AMR stream.
#define DSP_AFMT_MP2          0x0C // MP2 stream.
#define DSP_AFMT_ILBC         0x0D // iLBC stream.
#define DSP_AFMT_G729         0x0E // G.729 stream.
#define DSP_AFMT_AMRNB        0x0F // AMRNB stream.
#define DSP_AFMT_ALAW_DTX     0x10 // ALAW DTX stream.
#define DSP_AFMT_ULAW_DTX     0x11 // ULAW DTX stream.
#define DSP_AFMT_ILBC_DTX     0x12 // ILBC DTX stream.
#define DSP_AFMT_G729_DTX     0x13 // G.729 DTX stream.
#define DSP_AFMT_AMRNB_DTX    0x14 // AMRNB DTX stream.

/* Sample rates. */
#define SAMPLE_RATE_96KHZ     0x00
#define SAMPLE_RATE_88_2KHZ   0x01
#define SAMPLE_RATE_64KHZ     0x02
#define SAMPLE_RATE_48KHZ     0x03
#define SAMPLE_RATE_44_1KHZ   0x04
#define SAMPLE_RATE_32KHZ     0x05
#define SAMPLE_RATE_24KHZ     0x06
#define SAMPLE_RATE_22_05KHZ  0x07
#define SAMPLE_RATE_16KHZ     0x08
#define SAMPLE_RATE_12KHZ     0x09
#define SAMPLE_RATE_11_025KHZ 0x0A
#define SAMPLE_RATE_8KHZ      0x0B
#define SAMPLE_RATE_5_5125KHZ 0x0C

typedef struct volume_data {
    UNS_SINT dsp_cmd;
    UNS_SINT scale;
    SINT	 power2;
} VOLUME_DATA;

typedef struct panning_data {
    UNS_SINT dsp_cmd;
    UNS_SINT left_gain;
    UNS_SINT right_gain;
    UNS_SINT steps;
} PANNING_DATA;

typedef struct audio_status_info {
    UNS_SINT dsp_cmd;
    UNS_SINT stream_ID;
    UNS_SINT ds_stream_ID;
    UNS_SINT bridge_buffer_size;
    UNS_SINT mmap_buffer_size;
    UNS_SINT status;
    UNS_LGINT num_frames;
    UNS_SINT sample_rate;
    UNS_SINT number_channels;
    UNS_SINT vol_scale;
    SINT     vol_power2;
    SINT     left_gain;
    SINT     right_gain;
    SINT     dsp_audio_fmt;
    BOOL	 mute;
    UNS_LGINT  samples_played_high;
    UNS_LGINT  samples_played_low;
} AUDIO_STATUS_INFO;

typedef struct audio_init_status {
    UNS_SINT dsp_cmd;
    UNS_SINT init_status;
    UNS_SINT stream_ID;
    UNS_SINT bridge_buffer_size;
    UNS_SINT mmap_buffer_size;
} AUDIO_INIT_STATUS;

/* DSP audio task initialisation data. */
typedef struct audio_params_data {
    UNS_SINT dsp_cmd;
    UNS_SINT audio_fmt;
    UNS_SINT sample_rate;
    UNS_SINT number_channels;
    UNS_SINT ds_stream_ID;
    UNS_SINT stream_priority;
} AUDIO_PARAMS_DATA;

typedef struct {
    UNS_SINT dsp_cmd;
    UNS_SINT audio_fmt;
    UNS_SINT sample_rate;
    UNS_SINT ds_stream_ID;
    UNS_SINT stream_priority;
    UNS_SINT frame_size;
} SPEECH_PARAMS_DATA;

#endif // #ifndef __AUDIO_DSPTASK_H__
