/*
 * This file is part of  osso-dsp-headers-rx-44
 *
 * Copyright (C) 2006 Nokia Corporation. All rights reserved.
 *
 * Contact: Markku Vorne <markku.vorne@nokia.com>
 */

#ifndef __AUDIOPP_DSPTASK_H__
#define __AUDIOPP_DSPTASK_H__


#include "audio_dsptask.h"
#include "dsp_arm_types.h"

#define NUM_BANDS          5
#define LINE_SEGMENT_COUNT 5

#define MUSICDRC_MODE_HP            0
#define MUSICDRC_MODE_IHF           1
#define MUSICDRC_MODE_IHF_RX34      MUSICDRC_MODE_IHF
#define MUSICDRC_MODE_HS            2
#define MUSICDRC_MODE_IHF_RX44      3
#define MUSICDRC_MODE_BT            4


typedef struct EQ_RUNTIME_PARAMS {
    UNS_SINT dsp_cmd;      // Void; not used here
    UNS_SINT use_eq;       // Enable/disable equaliser.
    SINT     size;         // Void; added for future compatibility.
    UNS_SINT order;        // Filter order.
    SINT     bands;        // Number of bands.
    UNS_SINT band[10];     // Band limits.
    SINT     level_db[10]; // Band levels.
    UNS_SINT alignment;    //void not used here
} EQ_RUNTIME_PARAMS;

typedef struct MUSICDRC_RUNTIME_PARAMS {
    UNS_SINT dsp_cmd;      // DSP_CMD_SET_POSTPROC_MUSICDRC_PARAMS
    UNS_SINT alignment;    // Used for alignment purposes.

    /* For crossband control. */
    SINT     linkCoeffSelf;
    SINT     linkCoeffOthers;
    
    /* For limiter. */
    SINT     lim_attCoeff;
    SINT     lim_relCoeff;
    LGINT    limiterThreshold;  
    LGINT    limGain;  
    
    /* For attack and release time filtering. */
    LGINT    attCoeff[NUM_BANDS];
    LGINT    relCoeff[NUM_BANDS];
    
    /* For the average amplitude to gain calculation. */
    LGINT	 levelLimits[NUM_BANDS][LINE_SEGMENT_COUNT];
    LGINT    K[NUM_BANDS][LINE_SEGMENT_COUNT+1];
    LGINT    A[NUM_BANDS][LINE_SEGMENT_COUNT+1];
    
    /* For enable/disable MuMDRC algorithm */
    UNS_SINT use_mumdrc;  
    
    /* For tracing. */
    LGINT    Gain[NUM_BANDS];
    LGINT    amplitudes[NUM_BANDS]; 
	
    UNS_SINT mode;  

} MUSICDRC_RUNTIME_PARAMS;

typedef struct MUSICDRC_HPFILTER_COEFFS {
    UNS_SINT dsp_cmd;      // DSP_CMD_CHANGE_MUSICDRC_HPFILT_COEFFS
    UNS_SINT use_hpfilt;
    SINT     coeffs[32];
} MUSICDRC_HPFILTER_COEFFS;

typedef struct POSTPROCESSING_BYPASS_DATA {
    UNS_SINT dsp_cmd;           // 0x20
    UNS_SINT audio_pp_bypassed; // If set to 1, audio post proc. will
                                          // be bypassed.
} POSTPROCESSING_BYPASS_DATA;

#ifndef __TMS320C55X__
typedef struct IGEQ_Params {
    SINT     size;       // Must be the first variable in params struct
    UNS_SINT max_order;  // Maximum filter order.
    SINT     max_bands;  // Maximum number of bands.
    SINT     nb_samples; // Number of samples passed to FIR filter.
} IGEQ_Params;

typedef struct IMUMDRC_Params {
    /* For QMF framework. */
    SINT     maxDelayCompanderMs;
    UNS_SINT SampleRate;
    
    /* For hp-filter. */
    UNS_SINT max_nbr_iir_blocks;
    
    /* For limiter. */
    SINT     maxDelayLimiterMs;
} IMUMDRC_Params;
#endif

typedef struct POSTPROC_INIT_PARAMS {
    UNS_SINT 				 dsp_cmd;        // DSP_CMD_SET_POSTPROC_INIT_PARAMS
    UNS_SINT 				 alignment;  	 /*used for alignment purposes */
    AUDIO_PARAMS_DATA        audio_params;
    IGEQ_Params              EQ_init_params;      // Equaliser init parameters.
    EQ_RUNTIME_PARAMS        EQ_runtime_params;   // Equaliser runtime parameters
    IMUMDRC_Params           MUSICDRC_init_params;// Music DRC init parameters.
    MUSICDRC_RUNTIME_PARAMS  MUSICDRC_runtime_params;
    MUSICDRC_HPFILTER_COEFFS hp_filter_coeffs;
} POSTPROC_INIT_PARAMS;

typedef struct POSTPROC_ALGORITHM_PARAMS {
    UNS_SINT 				 dsp_cmd;             // DSP_CMD_GET_POSTPROC_PARAMS
    UNS_SINT 				 status;
    EQ_RUNTIME_PARAMS        EQ_runtime_params;
    MUSICDRC_RUNTIME_PARAMS  MUSICDRC_runtime_params;
    MUSICDRC_HPFILTER_COEFFS MUSICDRC_hpfilter_coeffs;
} POSTPROC_ALGORITHM_PARAMS;

#endif // #ifndef __AUDIOPP_DSPTASK_H__
